@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998-2008 David Faure <faure@kde.org>
-   Copyright (C) 2001 Holger Freyther <freyther@yahoo.com>
+    SPDX-FileCopyrightText: 1998-2008 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2001 Holger Freyther <freyther@yahoo.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "konq_popupmenu.h"
@@ -46,12 +33,12 @@
 #include <KIO/CommandLauncherJob>
 #include <kio_version.h>
 #include <KIO/OpenUrlJob>
+#include <KTerminalLauncherJob>
 #include <KFileCopyToMenu>
 #include <KJobWidgets>
 #include <KJobUiDelegate>
 #include <KMimeTypeEditor>
 #include <KPluginMetaData>
-#include <KToolInvocation>
 
 #include <QIcon>
 #include <QFileInfo>
@@ -398,19 +385,19 @@ void KonqPopupMenuPrivate::populate()
     }
 
     // Second block, builtin + user
-#if KIO_VERSION < QT_VERSION_CHECK(5, 77, 0)
-    m_menuActions.addServiceActionsTo(q);
-#else
     QList<QAction *> additionalActions;
     if (isDirectory && m_popupItemProperties.items().count() == 1) {
         QAction *openTerminalHere = new QAction(QIcon::fromTheme("utilities-terminal"), i18n("Open Terminal Here"), m_parentWidget);
         QObject::connect(openTerminalHere, &QAction::triggered, q, [this]() {
-            KToolInvocation::invokeTerminal(QString(),  m_popupItemProperties.urlList().constFirst().toLocalFile());
+                const QString localPath = m_popupItemProperties.urlList().constFirst().toLocalFile();
+                // 5.84 because the header wasn't usable in 5.83
+              auto *job = new KTerminalLauncherJob(QString{});
+              job->setWorkingDirectory(localPath);
+              job->start();
         });
         additionalActions << openTerminalHere;
     }
     m_menuActions.addActionsTo(q, KFileItemActions::MenuActionSource::Services, additionalActions);
-#endif
 
     q->addSeparator();
 
