@@ -29,7 +29,7 @@
 
 using namespace Akregator;
 
-K_PLUGIN_FACTORY(KonqFeedIconFactory, registerPlugin<KonqFeedIcon>();)
+K_PLUGIN_CLASS_WITH_JSON(KonqFeedIcon, "akregator_konqfeedicon.json")
 
 static QUrl baseUrl(KParts::ReadOnlyPart *part)
 {
@@ -42,7 +42,7 @@ static QUrl baseUrl(KParts::ReadOnlyPart *part)
 }
 
 KonqFeedIcon::KonqFeedIcon(QObject *parent, const QVariantList &args)
-    : KParts::Plugin(parent),
+    : KonqParts::Plugin(parent),
       m_part(nullptr),
       m_feedIcon(nullptr),
       m_statusBarEx(nullptr),
