@@ -43,11 +43,7 @@ PluginBabelFish::PluginBabelFish(QObject *parent,
     m_menu = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("Translate Web &Page"),
                              actionCollection());
     actionCollection()->addAction(QStringLiteral("translatewebpage"), m_menu);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
     m_menu->setPopupMode(QToolButton::InstantPopup);
-#else
-    m_menu->setDelayed(false);
-#endif
     connect(m_menu->menu(), SIGNAL(aboutToShow()),
             this, SLOT(slotAboutToShow()));
 
@@ -261,7 +257,7 @@ void PluginBabelFish::translateURL(QAction *action)
             QString title = i18nc("@title:window", "Malformed URL");
             QString text = i18n("The URL you entered is not valid, please "
                                 "correct it and try again.");
-            KMessageBox::sorry(part->widget(), text, title);
+            KMessageBox::error(part->widget(), text, title);
             return;
         }
     }
