@@ -79,9 +79,7 @@ class FSViewPart : public KParts::ReadOnlyPart
 public:
     FSViewPart(QWidget *parentWidget,
                QObject *parent,
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
                const KPluginMetaData& metaData,
-#endif
                const QList<QVariant> &args);
     ~FSViewPart() override;
 
