@@ -32,7 +32,7 @@
 #include "imgallerydialog.h"
 #include "imgallery_debug.h"
 
-K_PLUGIN_FACTORY(KImGalleryPluginFactory, registerPlugin<KImGalleryPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(KImGalleryPlugin, "kimgalleryplugin.json")
 
 // Eliminate lots of deprecation warnings with Qt 5.15.
 // Using a macro to redefine well known symbols is not good practice, but
@@ -46,7 +46,7 @@ static QString directory(const QUrl &url) {
 }
 
 KImGalleryPlugin::KImGalleryPlugin(QObject *parent, const QVariantList &)
-    : KParts::Plugin(parent), m_commentMap(nullptr)
+    : KonqParts::Plugin(parent), m_commentMap(nullptr)
 {
     QAction *a = actionCollection()->addAction(QStringLiteral("create_img_gallery"));
     a->setText(i18n("&Create Image Gallery..."));
@@ -59,13 +59,13 @@ void KImGalleryPlugin::slotExecute()
 {
     m_progressDlg = nullptr;
     if (!parent()) {
-        KMessageBox::sorry(nullptr, i18n("Could not create the plugin, please report a bug."));
+        KMessageBox::error(nullptr, i18n("Could not create the plugin, please report a bug."));
         return;
     }
     m_part = qobject_cast<KParts::ReadOnlyPart *>(parent());
 
     if (!m_part || !m_part->url().isLocalFile()) {  //TODO support remote URLs too?
-        KMessageBox::sorry(m_part->widget(), i18n("Creating an image gallery works only on local folders."));
+        KMessageBox::error(m_part->widget(), i18n("Creating an image gallery works only on local folders."));
         return;
     }
 
@@ -108,7 +108,7 @@ bool KImGalleryPlugin::createDirectory(const QDir &dir, const QString &imgGaller
     if (!thumb_dir.exists()) {
         thumb_dir.setPath(imgGalleryDir);
         if (!(thumb_dir.mkdir(dirName/*, false*/))) {
-            KMessageBox::sorry(m_part->widget(), i18n("Could not create folder: %1", thumb_dir.path()));
+            KMessageBox::error(m_part->widget(), i18n("Could not create folder: %1", thumb_dir.path()));
             return false;
         } else {
             thumb_dir.setPath(imgGalleryDir + '/' + dirName + '/');
@@ -272,7 +272,7 @@ bool KImGalleryPlugin::createHtml(const QUrl &url, const QString &sourceDirName,
             if (!subDir.exists()) {
                 subDir.setPath(directory(url));
                 if (!(subDir.mkdir(currentDir/*, false*/))) {
-                    KMessageBox::sorry(m_part->widget(), i18n("Could not create folder: %1", subDir.path()));
+                    KMessageBox::error(m_part->widget(), i18n("Could not create folder: %1", subDir.path()));
                     continue;
                 } else {
                     subDir.setPath(directory(url) + '/' + currentDir);
@@ -341,7 +341,7 @@ bool KImGalleryPlugin::createHtml(const QUrl &url, const QString &sourceDirName,
         if (!path.endsWith("/")) {
             path += '/';
         }
-        KMessageBox::sorry(m_part->widget(), i18n("Could not open file: %1", path));
+        KMessageBox::error(m_part->widget(), i18n("Could not open file: %1", path));
         return false;
     }
 }
@@ -436,7 +436,7 @@ void KImGalleryPlugin::loadCommentFile()
         qCDebug(IMAGEGALLERY_LOG) << "File closed.";
         delete m_textStream;
     } else {
-        KMessageBox::sorry(m_part->widget(), i18n("Could not open file: %1", m_configDlg->getCommentFile()));
+        KMessageBox::error(m_part->widget(), i18n("Could not open file: %1", m_configDlg->getCommentFile()));
         m_useCommentFile = false;
     }
 }
