@@ -1,19 +1,7 @@
 /*
-Copyright (C) 2008 Xavier Vello <xavier.vello@gmail.com>
+    SPDX-FileCopyrightText: 2008 Xavier Vello <xavier.vello@gmail.com>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -30,7 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KConfigGroup>
 #include <kimagecache.h>
 
-K_PLUGIN_FACTORY_DECLARATION(KioConfigFactory)
+K_PLUGIN_CLASS_WITH_JSON(BookmarksConfigModule, "bookmarks.json")
 
 BookmarksConfigModule::BookmarksConfigModule(QWidget *parent, const QVariantList &)
     : KCModule(parent)
@@ -110,4 +98,4 @@ void BookmarksConfigModule::configChanged()
     emit changed(true);
 }
 
-//
+#include "bookmarks.moc"
