@@ -1,11 +1,10 @@
 /*
- * "Misc Options" Tab for KFM configuration
- *
- * Copyright (C) Sven Radej 1998
- * Copyright (C) David Faure 1998
- * Copyright (C) 2001 Waldo Bastian <bastian@kde.org>
- *
- */
+    "Misc Options" Tab for KFM configuration
+
+    SPDX-FileCopyrightText: 1998 Sven Radej
+    SPDX-FileCopyrightText: 1998 David Faure
+    SPDX-FileCopyrightText: 2001 Waldo Bastian <bastian@kde.org>
+*/
 
 // Own
 #include "htmlopts.h"
