@@ -1,23 +1,23 @@
 /*
- * Copyright (c) Martin R. Jones 1996
- * Copyright (c) Bernd Wuebben 1998
- *
- * Copyright (c) Torben Weis 1998
- *     KControl port & modifications
- *
- * Copyright (c) David Faure 1998
- *     End of the KControl port, added 'kfmclient configure' call.
- *
- * Copyright (C) Kalle Dalheimer 2000
- *     New configuration scheme for JavaScript
- *
- * Copyright (c) Daniel Molkentin 2000
- *     Major cleanup & Java/JS settings split
- *
- * Copyright (c) Leo Savernik 2002-2003
- *     Big changes to accommodate per-domain settings
- *
- */
+    SPDX-FileCopyrightText: 1996 Martin R. Jones
+    SPDX-FileCopyrightText: 1998 Bernd Wuebben
+
+    SPDX-FileCopyrightText: 1998 Torben Weis
+    KControl port & modifications
+
+    SPDX-FileCopyrightText: 1998 David Faure
+    End of the KControl port, added 'kfmclient configure' call.
+
+    SPDX-FileCopyrightText: 2000 Kalle Dalheimer
+    New configuration scheme for JavaScript
+
+    SPDX-FileCopyrightText: 2000 Daniel Molkentin
+    Major cleanup & Java/JS settings split
+
+    SPDX-FileCopyrightText: 2002-2003 Leo Savernik
+    Big changes to accommodate per-domain settings
+
+*/
 
 // Own
 #include "jsopts.h"
