@@ -68,11 +68,7 @@ public:
     /**
      * Default constructor
      */
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
     KonqSidebarPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData& metaData, const QVariantList &);
-#else
-    KonqSidebarPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
-#endif
 
     /**
      * Destructor
