@@ -18,22 +18,16 @@
 
 // KDE
 #include <kxmlguifactory.h>
-#include <kconfig.h>
 #include "konqdebug.h"
-#include <kparts_version.h>
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+#include "konq_kpart_plugin.h"
 #include <KPluginMetaData>
-#else
-#include <KAboutData>
-#endif
+#include <KConfigGroup>
+#include <KFileUtils>
 #include <KLocalizedString>
-#include <kparts/plugin.h>
-#include <kplugininfo.h>
-#include <kpluginselector.h>
+#include <KPluginWidget>
+#include <KSharedConfig>
 #include <ksettings/dispatcher.h>
 #include <kstandardguiitem.h>
-#include <KSharedConfig>
-#include <KConfigGroup>
 
 // Local
 #include "konqview.h"
@@ -42,7 +36,7 @@
 class KonqExtensionManagerPrivate
 {
 public:
-    KPluginSelector *pluginSelector;
+    KPluginWidget *pluginSelector;
     KonqMainWindow *mainWindow;
     KParts::ReadOnlyPart *activePart;
     QDialogButtonBox *buttonBox;
@@ -61,25 +55,27 @@ KonqExtensionManager::KonqExtensionManager(QWidget *parent, KonqMainWindow *main
 
     resize(QSize(640, 480)); // FIXME: hard-coded values ?
 
-    d->pluginSelector = new KPluginSelector(this);
+    d->pluginSelector = new KPluginWidget(this);
     mainLayout->addWidget(d->pluginSelector);
     connect(d->pluginSelector, SIGNAL(changed(bool)), this, SLOT(setChanged(bool)));
-    connect(d->pluginSelector, SIGNAL(configCommitted(QByteArray)),
-            this, SLOT(reparseConfiguration(QByteArray)));
+    connect(d->pluginSelector, &KPluginWidget::pluginConfigSaved, this, [this](const QString &pluginId) {
+        reparseConfiguration(pluginId.toLocal8Bit());
+    });
 
     d->mainWindow = mainWindow;
     d->activePart = activePart;
 
-    d->pluginSelector->addPlugins(QStringLiteral("konqueror"), i18n("Extensions"), QStringLiteral("Extensions"), KSharedConfig::openConfig());
+    auto addPluginForId = [this](const QString &pluginId) {
+        QVector<KPluginMetaData> metaDataList = KPluginMetaData::findPlugins(pluginId + QStringLiteral("/kpartplugins"));
+        d->pluginSelector->addPlugins(metaDataList, i18n("Extensions"));
+    };
     if (activePart) {
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
-        const QString pluginId = activePart->metaData().pluginId();
-#else
-        const QString pluginId = activePart->componentData().componentName();
-#endif
-        d->pluginSelector->addPlugins(pluginId, i18n("Extensions"), QStringLiteral("Tools"));
-        d->pluginSelector->addPlugins(pluginId, i18n("Extensions"), QStringLiteral("Statusbar"));
+        d->pluginSelector->setConfig(KSharedConfig::openConfig(activePart->metaData().pluginId() + QLatin1String("rc"))->group("KParts Plugins"));
+        addPluginForId(activePart->metaData().pluginId());
+    } else {
+        d->pluginSelector->setConfig(KSharedConfig::openConfig(QStringLiteral("konquerorrc"))->group("KParts Plugins"));
     }
+    addPluginForId(QStringLiteral("konqueror")); // Always add the plugins from the konqueror namespace
 
     d->buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::RestoreDefaults|QDialogButtonBox::Apply);
     QPushButton *okButton = d->buttonBox->button(QDialogButtonBox::Ok);
@@ -91,8 +87,6 @@ KonqExtensionManager::KonqExtensionManager(QWidget *parent, KonqMainWindow *main
     connect(okButton, SIGNAL(clicked()), SLOT(slotOk()));
     connect(d->buttonBox->button(QDialogButtonBox::Apply), SIGNAL(clicked()), SLOT(slotApply()));
     connect(d->buttonBox->button(QDialogButtonBox::RestoreDefaults), SIGNAL(clicked()), SLOT(slotDefault()));
-
-    d->pluginSelector->load();
 }
 
 KonqExtensionManager::~KonqExtensionManager()
@@ -118,8 +112,7 @@ void KonqExtensionManager::apply()
         setChanged(false);
 
         if (d->mainWindow) {
-            KParts::Plugin::loadPlugins(d->mainWindow, d->mainWindow, QStringLiteral("konqueror"));
-            QList<KParts::Plugin *> plugins = KParts::Plugin::pluginObjects(d->mainWindow);
+            QList<KonqParts::Plugin *> plugins = KonqParts::Plugin::pluginObjects(d->mainWindow);
 
             for (int i = 0; i < plugins.size(); ++i) {
                 d->mainWindow->factory()->addClient(plugins.at(i));
@@ -127,8 +120,8 @@ void KonqExtensionManager::apply()
         }
 
         if (d->activePart) {
-            KParts::Plugin::loadPlugins(d->activePart, d->activePart, d->activePart->componentName());
-            QList<KParts::Plugin *> plugins = KParts::Plugin::pluginObjects(d->activePart);
+            KonqParts::Plugin::loadPlugins(d->activePart, d->activePart, d->activePart->componentName());
+            QList<KonqParts::Plugin *> plugins = KonqParts::Plugin::pluginObjects(d->activePart);
 
             for (int i = 0; i < plugins.size(); ++i) {
                 d->activePart->factory()->addClient(plugins.at(i));
