@@ -426,7 +426,7 @@ private Q_SLOTS:
 
     void slotDumpDebugInfo();
 
-    void slotOpenEmbedded(KService::Ptr);
+    void slotOpenEmbedded(const KPluginMetaData &part);
 
     // Connected to KGlobalSettings
     void slotReconfigure();
@@ -604,6 +604,10 @@ private:
     QObject *lastFrame(KonqView *view);
 
     QLineEdit *comboEdit();
+
+    void saveGlobalProperties(KConfig * sessionConfig) override;
+
+    void readGlobalProperties(KConfig * sessionConfig) override;
     
 private: // members
     KonqUndoManager *m_pUndoManager;
