@@ -25,6 +25,7 @@ class KJob;
 namespace KIO {
     class OpenUrlJob;
     class ApplicationLauncherJob;
+    class MimeTypeFinderJob;
 }
 
 class KonqMainWindow;
@@ -65,6 +66,7 @@ public:
     UrlLoader(KonqMainWindow *mainWindow, KonqView *view, const QUrl &url, const QString &mimeType, const KonqOpenURLRequest &req, bool trustedSource, bool forceOpen=false);
     ~UrlLoader();
 
+
     /** @brief Enum describing the possible actions to be taken*/
     enum class OpenUrlAction{
         UnknwonAction, /**< The action hasn't been decided yet */
@@ -128,11 +130,18 @@ public:
     bool isAsync() const {return m_isAsync;}
     void setOldLocationBarUrl(const QString &old);
     QString oldLocationBarUrl() const {return m_oldLocationBarUrl;}
-    bool hasError() const {return m_jobHadError;}
+    bool hasError() const {return m_jobErrorCode;}
     void setNewTab(bool newTab);
     static bool isExecutable(const QString &mimeType);
     QString suggestedFileName() const {return m_request.suggestedFileName;}
 
+    /**
+     * @brief The @c ID of the part to use to open a local file
+     *
+     * @param path the file path
+     * @return the plugin id for the preferred part for @p file (as returned by @c KPluginMetaData::pluginId() or
+     * an empty string if no part could be found
+     */
     static QString partForLocalFile(const QString &path);
 
 signals:
@@ -140,7 +149,7 @@ signals:
 
 private slots:
 
-    void mimetypeDeterminedByJob(const QString &mimeType);
+    void mimetypeDeterminedByJob();
     void jobFinished(KJob* job);
     void done(KJob *job=nullptr);
 
@@ -155,7 +164,7 @@ private:
     void saveUrlUsingKIO(const QUrl &orig, const QUrl &dest);
     void detectSettingsForLocalFiles();
     void detectSettingsForRemoteFiles();
-    void launchOpenUrlJob(bool pauseOnMimeTypeDetermined);
+    void launchMimeTypeFinderJob();
     static bool isTextExecutable(const QString &mimeType);
     void openExternally();
     void killOpenUrlJob();
@@ -185,12 +194,15 @@ private:
     bool m_ready = false;
     bool m_isAsync = false;
     OpenUrlAction m_action = OpenUrlAction::UnknwonAction;
+    KPluginMetaData m_part;
     KService::Ptr m_service;
     QPointer<KIO::OpenUrlJob> m_openUrlJob;
     QPointer<KIO::ApplicationLauncherJob> m_applicationLauncherJob;
+    QPointer<KIO::MimeTypeFinderJob> m_mimeTypeFinderJob;
     QString m_oldLocationBarUrl;
-    bool m_jobHadError;
+    int m_jobErrorCode;
     bool m_dontPassToWebEnginePart;
+    bool m_protocolAllowsReading;
 };
 
 QDebug operator<<(QDebug dbg, UrlLoader::OpenUrlAction action);
