@@ -15,14 +15,20 @@
 #include "webenginepartcookiejar.h"
 #include "spellcheckermanager.h"
 #include "webenginepartdownloadmanager.h"
+#include "certificateerrordialogmanager.h"
+#include "webenginewallet.h"
+#include "webenginepart.h"
 
 #include <KProtocolInfo>
 
 #include <QWebEngineProfile>
 #include <QWebEngineUrlScheme>
+#include <QWebEngineSettings>
+#include <QWebEngineScriptCollection>
 
 WebEnginePartControls::WebEnginePartControls(): QObject(),
-    m_profile(nullptr), m_cookieJar(nullptr), m_spellCheckerManager(nullptr), m_downloadManager(nullptr)
+    m_profile(nullptr), m_cookieJar(nullptr), m_spellCheckerManager(nullptr), m_downloadManager(nullptr),
+    m_certificateErrorDialogManager(new KonqWebEnginePart::CertificateErrorDialogManager(this))
 {
         QVector<QByteArray> localSchemes = {"error", "konq", "tar"};
         const QStringList protocols = KProtocolInfo::protocols();
@@ -61,6 +67,8 @@ void WebEnginePartControls::setup(QWebEngineProfile* profile)
     }
     m_profile = profile;
 
+    m_profile->scripts()->insert({WebEngineWallet::formDetectorFunctionsScript(), WebEnginePart::detectRefreshScript()});
+
     m_profile->installUrlSchemeHandler("error", new WebEnginePartErrorSchemeHandler(m_profile));
     m_profile->installUrlSchemeHandler("konq", new KonqUrlSchemeHandler(m_profile));
     m_profile->installUrlSchemeHandler("help", new WebEnginePartKIOHandler(m_profile));
@@ -71,6 +79,7 @@ void WebEnginePartControls::setup(QWebEngineProfile* profile)
     m_cookieJar = new WebEnginePartCookieJar(profile, this);
     m_spellCheckerManager = new SpellCheckerManager(profile, this);
     m_downloadManager= new WebEnginePartDownloadManager(profile, this);
+    m_profile->settings()->setAttribute(QWebEngineSettings::ScreenCaptureEnabled, true);
 }
 
 WebEnginePartDownloadManager* WebEnginePartControls::downloadManager() const
@@ -82,3 +91,8 @@ SpellCheckerManager* WebEnginePartControls::spellCheckerManager() const
 {
     return m_spellCheckerManager;
 }
+
+bool WebEnginePartControls::handleCertificateError(const QWebEngineCertificateError& ce, WebEnginePage* page)
+{
+    return m_certificateErrorDialogManager->handleCertificateError(ce, page);
+}
