@@ -1,31 +1,17 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2008 Laurent Montel <montel@kde.org>
- *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published by the
- * Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
- * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KDE project.
+
+    SPDX-FileCopyrightText: 2008 Laurent Montel <montel@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "webenginepartfactory.h"
 #include "webenginepart_ext.h"
 #include "webenginepart.h"
 
 #include <kparts_version.h>
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
 #include <KPluginMetaData>
-#endif
 
 #include <QWidget>
 
@@ -46,11 +32,7 @@ QObject *WebEngineFactory::create(const char* iface, QWidget *parentWidget, QObj
     // history management with any KParts based application.
     QByteArray histData (m_historyBufContainer.value(parentWidget));
     if (!histData.isEmpty()) histData = qUncompress(histData);
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
     WebEnginePart* part = new WebEnginePart(parentWidget, parent, metaData(), histData);
-#else
-    WebEnginePart* part = new WebEnginePart(parentWidget, parent, histData);
-#endif
     WebEngineBrowserExtension* ext = qobject_cast<WebEngineBrowserExtension*>(part->browserExtension());
     if (ext) {
         connect(ext, QOverload<QObject *, const QByteArray &>::of(&WebEngineBrowserExtension::saveHistory),
