@@ -28,6 +28,7 @@
 #include <KStringHandler>
 #include <KLocalizedString>
 #include <KIO/CommandLauncherJob>
+#include <KParts/BrowserInterface>
 
 #include <QTimer>
 #include <QMimeData>
@@ -71,8 +72,13 @@ WebEngineView::~WebEngineView()
     //qCDebug(WEBENGINEPART_LOG);
 }
 
-void WebEngineView::loadUrl(const QUrl& url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& bargs)
+void WebEngineView::loadUrl(const QUrl& url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& bargs, bool force)
 {
+    WebEnginePage *pg = qobject_cast<WebEnginePage*>(page());
+    if (!pg) {
+        return;
+    }
+
     page()->setProperty("NavigationTypeUrlEntered", true);
 
     if (args.reload() && url == this->url()) {
@@ -80,10 +86,10 @@ void WebEngineView::loadUrl(const QUrl& url, const KParts::OpenUrlArguments& arg
       return;
     }
 
-    QNetworkRequest request(url);
-    if (args.reload()) {
-        request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::AlwaysNetwork);
-    }
+//     QNetworkRequest request(url);
+//     if (args.reload()) {
+//         request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::AlwaysNetwork);
+//     }
 
     if (bargs.postData.isEmpty()) {
         QWebEngineView::load(url);
@@ -607,3 +613,38 @@ void WebEngineView::addSearchActions(QList<QAction*>& selectActions, QWebEngineV
         }
     }
 }
+
+void WebEngineView::acceptDragMoveEventIfPossible(QDragMoveEvent* e)
+{
+    if (!e->isAccepted() && e->mimeData()->hasUrls()) {
+        e->acceptProposedAction();
+        m_dragAndDropHandledBySuperclass = false;
+    } else {
+        m_dragAndDropHandledBySuperclass = true;
+    }
+}
+
+void WebEngineView::dropEvent(QDropEvent* e)
+{
+    QWebEngineView::dropEvent(e);
+    //Unlike in acceptProposedDragEventIfPossible, we don't check !e->isAccepted because it seems that it's always true
+    //(if the move event was accepted, this is accepted automatically; if the move event was rejected, this function
+    //isn't called at all)
+    if (!m_dragAndDropHandledBySuperclass && e->mimeData()->hasUrls()) {
+        m_dragAndDropHandledBySuperclass = true;
+        emit m_part->browserExtension()->openUrlRequest(e->mimeData()->urls().first());
+        e->acceptProposedAction();
+    }
+}
+
+void WebEngineView::dragEnterEvent(QDragEnterEvent* e)
+{
+    QWebEngineView::dragEnterEvent(e);
+    acceptDragMoveEventIfPossible(e);
+}
+
+void WebEngineView::dragMoveEvent(QDragMoveEvent* e)
+{
+    QWebEngineView::dragMoveEvent(e);
+    acceptDragMoveEventIfPossible(e);
+}
