@@ -55,7 +55,6 @@ class MainWindow : public QMainWindow
     Q_OBJECT
 public:
     MainWindow(const QString& url = QString()): currentZoom(100) {
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
         QJsonObject jo = QJsonDocument::fromJson(
             "{ \"KPlugin\": {\n"
             " \"Id\": \"webenginepart\",\n"
@@ -64,9 +63,6 @@ public:
             "}\n}").object();
         KPluginMetaData metaData(jo, QString());
         view = new WebEnginePart(this, nullptr, metaData);
-#else
-        view = new WebEnginePart(this, nullptr);
-#endif
         setCentralWidget(view->widget());
 
         connect(view->view(), &QWebEngineView::loadFinished,
